{% extends "base.html" %}
{% load i18n %}

{% block title %}
  {% trans "E-mail envoyé" %}
{% endblock %}

{% block content %}

<p class="text-semibold text-color-primary">
  Please, check your mailbox
</p>

<p class="text-color-primary">
  We have just sent you the instructions to define your password.
</p>

<div class="segment full margin-top-large">
  <a class="link" style="color: var(--color-primary); font-size: 0.8em;" href="https://bsgn.spacecoop.eu/legal_T&C.html">Terms & Conditions</a>&nbsp;-&nbsp;<a class="link" style="color: var(--color-primary); font-size: 0.8em;" href="https://bsgn.spacecoop.eu/legal_DPP.html">Privacy Policy</a>
</div>

{% endblock %}