{% extends "base.html" %}
{% load i18n %}

{% block title %}
  {% trans "Mot de passe modifié" %}
{% endblock %}

{% block content %}

<p class="text-semibold text-color-heading">
  {% trans "Mot de passe modifié" %}.
</p>

<div class="segment full margin-top-xsmall">
  <a style="color: var(--color-primary); font-size: 0.8em;" class="button button-icon text-xsmall text-bold text-uppercase text-color-primary bordered icon-rocket icon-small icon-margin-right-xsmall" href="{% url 'login' %}">
    {% trans "Se connecter" %}
  </a>
</div>

{% endblock %}