{% load i18n %}
{% load orbit %}
{% load static %}
{% get_current_language as LANGUAGE_CODE %}{% get_current_language_bidi as LANGUAGE_BIDI %}
<!DOCTYPE html>
<html lang="{{ LANGUAGE_CODE|default:"en-us" }}"{% if LANGUAGE_BIDI %} dir="rtl"{% endif %}>
  <head>
    <meta charset="UTF-8" />
    <title>{% orbit 'client_settings.name' %} - {% block title %}{{ title }}{% endblock %}</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <meta http-equiv="X-UA-Compatible" content="ie=edge" />
    <link rel="preconnect" href="https://fonts.gstatic.com" />
    <link rel="stylesheet" href="https://fonts.googleapis.com/css2?family=Open+Sans:ital,wght@0,300;0,400;0,600;0,700;0,800;1,300;1,400;1,600;1,700;1,800&amp;display=swap" />
    <link rel="stylesheet" href="https://cdn.startinblox.com/orbit-styling-framework/index.css" />
    <link rel="stylesheet" href="{% static 'css/main.css' %}{% if debug_flag %}?{% now 'U' %}{% endif %}" />
    {% block extrastyle %}{% endblock %}
    {% if "css" in client_settings %}
    <link rel="stylesheet" href="{% orbit 'client.css' %}" />
    {% endif %}
    {% if "favicon" in client_settings %}
    <link rel="icon" type="image/webp" href="{% orbit 'client.favicon' %}">
    {% else %}
    <link rel="icon" type="image/webp" href="{% static 'images/favicon.webp' %}">
    {% endif %}
    {% block extrahead %}{% endblock %}
  </head>

  <body>
    <div class="segment full whitespace-normal">
      <div class="whitespace-normal padding-top-xxlarge padding-right-xsmall padding-bottom-xlarge padding-left-xsmall sm-padding-top-medium bg-color-secondary text-center content-index">
        <div class="segment two-third sm-full bg-color-white shadow border-rounded-xxsmall whitespace-normal">
            <div class="instance-logo">
              <img src="https://cdn.startinblox.com/logos/bsgn-sce.png" style="max-width: 80%; max-height: 80%" />
            </div>
          {% if debug_flag %}{% orbit "errors" %}{% endif %}
          <div class="segment full sm-full whitespace-normal">
            {% block content %}{% autoescape off %}{{ content }}{% endautoescape %}{% endblock %}
          </div>
        </div>
      </div>
    </div>
  </body>
</html>
