{% extends "base.html" %}
{% load i18n %}

{% block title %}
  {% trans "Mot de passe réinitialisé avec succès" %}
{% endblock %}

{% block content %}

<p class="text-semibold text-color-heading">
  {% trans "Mot de passe réinitialisé avec succès" %}.
</p>

<div class="segment full margin-top-xsmall">
  <a style="background-color: var(--color-primary); color: white;" class="button reversed button-icon text-xsmall text-bold text-uppercase color-secondary icon-rocket icon-small icon-margin-right-xsmall" href="{% url 'login' %}">
    {% trans "Se connecter" %}
  </a>
</div>

<div class="segment full margin-top-large">
  <a class="link" style="color: var(--color-primary); font-size: 0.8em;" href="https://bsgn.spacecoop.eu/legal_T&C.html">Terms & Conditions</a>&nbsp;-&nbsp;<a class="link" style="color: var(--color-primary); font-size: 0.8em;" href="https://bsgn.spacecoop.eu/legal_DPP.html">Privacy Policy</a>
</div>
{% endblock %}